@@ -11,6 +11,7 @@ Functions for testing Sphinx extensions.
 
 .. latex:vspace:: 45px
 
+.. _pytest-regressions: https://pypi.org/project/pytest-regressions/
 """
 #
 #  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -63,9 +64,11 @@ Functions for testing Sphinx extensions.
 
 # stdlib
 import copy
+import sys
 import tempfile
+from functools import partial
 from types import SimpleNamespace
-from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple, Type, Union
+from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple, Type, Union, cast
 
 # 3rd party
 import pytest  # nodep
@@ -79,12 +82,13 @@ from domdf_python_tools.doctools import prettify_docstrings
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import PathLike
+from jinja2 import Template  # nodep
 from pygments.lexer import Lexer  # type: ignore  # nodep
+from pytest_regressions.common import check_text_files  # nodep
 from pytest_regressions.file_regression import FileRegressionFixture  # nodep
 from sphinx.builders import Builder
 from sphinx.config import Config
 from sphinx.domains import Domain, Index
-# from sphinx.environment.collectors import EnvironmentCollector
 from sphinx.domains.python import PythonDomain
 from sphinx.environment.collectors import EnvironmentCollector
 from sphinx.events import EventListener
@@ -233,7 +237,7 @@ class Sphinx:
 			self,
 			node: Type[nodes.Element],
 			figtype: str,
-			title_getter: TitleGetter = None,
+			title_getter: Optional[TitleGetter] = None,
 			override: bool = False,
 			**kwargs: Tuple[Callable, Callable],
 			) -> None:
@@ -241,7 +245,13 @@ class Sphinx:
 		Register a Docutils node class as a numfig target.
 		"""
 
-		self.registry.add_enumerable_node(node, figtype, title_getter, override=override)
+		# Sphinx's signature is wrong WRT Optional
+		self.registry.add_enumerable_node(
+				node,
+				figtype,
+				title_getter,  # type: ignore
+				override=override,
+				)
 		self.add_node(node, override=override, **kwargs)
 
 	def add_directive(self, name: str, cls: Type[Directive], override: bool = False) -> None:
@@ -334,8 +344,8 @@ class Sphinx:
 			directivename: str,
 			rolename: str,
 			indextemplate: str = '',
-			parse_node: Callable = None,
-			ref_nodeclass: Type[nodes.TextElement] = None,
+			parse_node: Optional[Callable] = None,
+			ref_nodeclass: Optional[Type[nodes.TextElement]] = None,
 			objname: str = '',
 			doc_field_types: List = [],
 			override: bool = False,
@@ -344,12 +354,13 @@ class Sphinx:
 		Register a new object type.
 		"""
 
+		# Sphinx's signature is wrong WRT Optional
 		self.registry.add_object_type(
 				directivename,
 				rolename,
 				indextemplate,
-				parse_node,
-				ref_nodeclass,
+				parse_node,  # type: ignore
+				ref_nodeclass,  # type: ignore
 				objname,
 				doc_field_types,
 				override=override,
@@ -360,7 +371,7 @@ class Sphinx:
 			directivename: str,
 			rolename: str,
 			indextemplate: str = '',
-			ref_nodeclass: Type[nodes.TextElement] = None,
+			ref_nodeclass: Optional[Type[nodes.TextElement]] = None,
 			objname: str = '',
 			override: bool = False,
 			) -> None:
@@ -368,11 +379,12 @@ class Sphinx:
 		Register a new crossref object type.
 		"""
 
+		# Sphinx's signature is wrong WRT Optional
 		self.registry.add_crossref_type(
 				directivename,
 				rolename,
 				indextemplate,
-				ref_nodeclass,
+				ref_nodeclass,  # type: ignore
 				objname,
 				override=override,
 				)
@@ -419,14 +431,15 @@ class Sphinx:
 	def add_latex_package(
 			self,
 			packagename: str,
-			options: str = None,
+			options: Optional[str] = None,
 			after_hyperref: bool = False,
 			) -> None:
 		"""
 		Register a package to include in the LaTeX source code.
 		"""
 
-		self.registry.add_latex_package(packagename, options, after_hyperref)  # type: ignore
+		# Sphinx's signature is wrong WRT Optional
+		self.registry.add_latex_package(packagename, cast(str, options), after_hyperref)
 
 	def add_lexer(self, alias: str, lexer: Type[Lexer]) -> None:
 		"""
@@ -540,7 +553,7 @@ class RunSetupOutput(NamedTuple):
 	directives: Dict[str, Callable]  #: Mapping of directive names to directive functions.
 	roles: Dict[str, Callable]  #: Mapping of role names to role functions.
 	additional_nodes: Set[Type[Any]]  #: Set of custom docutils nodes registered in ``setup()``.
-	app: Sphinx  #: Instance of :class:`sphinx-toolbox.testing.Sphinx`.
+	app: Sphinx  #: Instance of :class:`sphinx_toolbox.testing.Sphinx`.
 
 
 _sphinx_dict_setup = Callable[[sphinx.application.Sphinx], Optional[Dict[str, Any]]]
@@ -620,8 +633,7 @@ def remove_html_link_tags(page: BeautifulSoup) -> BeautifulSoup:
 
 def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFixture):
 	"""
-	Check an HTML page generated by Sphinx for regressions,
-	using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`_
+	Check an HTML page generated by Sphinx for regressions, using `pytest-regressions`_.
 
 	:param page: The page to test.
 	:param file_regression: The file regression fixture.
@@ -633,7 +645,7 @@ def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFi
 		@pytest.mark.parametrize("page", ["index.html"], indirect=True)
 		def test_page(page: BeautifulSoup, file_regression: FileRegressionFixture):
 			check_html_regression(page, file_regression)
-	"""  # noqa D400
+	"""  # noqa: RST306
 
 	__tracebackhide__ = True
 
@@ -656,21 +668,35 @@ def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFi
 
 class HTMLRegressionFixture(FileRegressionFixture):
 	"""
-	Subclass of :class:`pytest_regressions.file_regression.FileRegressionFixture`
-	for checking HTML files.
+	Subclass of :class:`pytest_regressions.file_regression.FileRegressionFixture` for checking HTML files.
 
 	.. versionadded:: 2.0.0
-	"""  # noqa: D400
+	"""
 
-	def check(self, page: BeautifulSoup, *, extension: str = ".html", **kwargs):  # type: ignore
+	def check(  # type: ignore
+		self,
+		page: BeautifulSoup,
+		*,
+		extension: str = ".html",
+		jinja2: bool = False,
+		**kwargs
+		):
 		r"""
-		Check an HTML page generated by Sphinx for regressions,
-		using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`__
+		Check an HTML page generated by Sphinx for regressions, using `pytest-regressions`_.
 
 		:param page: The page to test.
+		:param jinja2: Whether to render the reference file as a jinja2 template.
 		:param \*\*kwargs: Additional keyword arguments passed to
 			:meth:`pytest_regressions.file_regression.FileRegressionFixture.check`.
 
+		.. versionchanged:: 2.14.0  Added the ``jinja2`` keyword argument.
+
+		When ``jinja2`` is :py:obj:`True`, the reference file will be rendered as a jinja2 template.
+		The template is passed the following variables:
+
+		* ``sphinx_version`` -- the Sphinx version number, as a tuple of integers.
+		* ``python_version`` -- the Python version number, in the form returned by :data:`sys.version_info`.
+
 		**Example usage**
 
 		.. code-block:: python
@@ -678,7 +704,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 			@pytest.mark.parametrize("page", ["index.html"], indirect=True)
 			def test_page(page: BeautifulSoup, html_regression: HTMLRegressionFixture):
 				html_regression.check(page, file_regression)
-		"""  # noqa D400
+		"""  # noqa: RST306
 
 		__tracebackhide__ = True
 
@@ -695,17 +721,38 @@ class HTMLRegressionFixture(FileRegressionFixture):
 		kwargs.pop("encoding", None)
 		kwargs.pop("extension", None)
 
+		if jinja2:
+
+			def check_fn(obtained_filename, expected_filename):
+				__tracebackhide__ = True
+
+				expected_filename = PathPlus(expected_filename)
+				template = Template(expected_filename.read_text())
+
+				expected_filename.write_text(
+						template.render(
+								sphinx_version=sphinx.version_info,
+								python_version=sys.version_info,
+								)
+						)
+
+				return check_text_files(obtained_filename, expected_filename, encoding="UTF-8")
+
+		else:
+			check_fn = partial(check_text_files, encoding="UTF-8")
+
 		super().check(
 				str(StringList(page.prettify())),
 				encoding="UTF-8",
 				extension=extension,
+				check_fn=check_fn,
 				)
 
 
 @pytest.fixture()
 def html_regression(datadir, original_datadir, request) -> HTMLRegressionFixture:
 	"""
-	Returns a :class:`~.HTMLRegressionFixture` scoped to the test function.
+	Returns an :class:`~.HTMLRegressionFixture` scoped to the test function.
 
 	.. versionadded:: 2.0.0
 	"""
